@@ -147,6 +147,29 @@ class Base(Controller):
         else:
             raise NotImplementedError("Choose one of {ls, update, start, stop}")
 
+    @ex(
+        help='Tree helper/replacement functions',
+        arguments= [
+            (['loc'], {
+                "help": "Location of the tree to act on",
+                "action": "store"
+            }),
+            (['-n'],{
+                "help": "Depth of the tree to print",
+                "action": "store"
+            })
+        ]
+    )
+    def tree(self):
+        from ..ext.tree import tree
+        
+        try:
+            level = int(self.app.pargs.n)
+        except TypeError:
+            level = 2
+        tree(self.app.pargs.loc, level)
+        
+
     @ex(
         help="AWS EC2 helper commands.",
         arguments=[
@@ -214,6 +237,7 @@ class Base(Controller):
                 "help" : "To give the SFTP server a name.",
                 "action" : "store"
             }),
+            # TODO: there's some weird bug when grabbing this.
             (['-i', '--identity'],{
                 "help" : "Path to the identity file to use for ssh.",
                 "action" : "store"
@@ -225,6 +249,7 @@ class Base(Controller):
         ]
     )
     def sftp(self):
+        import ipdb; ipdb.set_trace()
         ip = self.app.pargs.ip
         remote = self.app.pargs.__dict__.get('remote') or self.app.pargs.__dict__.get('r') or '/data/openpilot'
         port = self.app.pargs.__dict__.get('port') or self.app.pargs.__dict__.get('p') or 8022
