@@ -11,7 +11,7 @@ def parse_keys(x):
     except:
         print("one of the instances does not have a name")
 
-def get_ec2(status: str, profile: str, filter: str):
+def get_ec2(status: str, profile: str, filter: str, region: str):
     possible_filters = dict(
         live=[{"Name":"instance-state-name", "Values":["running"] }],
         all=[]
@@ -19,13 +19,13 @@ def get_ec2(status: str, profile: str, filter: str):
 
     filters = possible_filters[filter]
 
-    ec2 = boto3.session.Session(profile_name=profile, region_name='eu-west-1').client('ec2')
+    ec2 = boto3.session.Session(profile_name=profile, region_name=region).client('ec2')
     live_inst = ec2.describe_instances(Filters=filters)
     df = pd.DataFrame(live_inst['Reservations'])
     try:
         df_list = [ pd.DataFrame.from_dict(x[0], orient='index') for x in df['Instances'].values ]
     except KeyError as e:
-        return f'No instances running for {profile} with filter {filter}'
+        return f'No instances running for {profile} with filter {filter} in {region}.'
     full_df = pd.concat(df_list,axis=1, sort=True).T
 
     full_df['SG'] = [ ','.join([i['GroupName'] for i in f ]) for f in  full_df.SecurityGroups  ] 
