@@ -16,7 +16,7 @@ def write_sftp(name: str, remote: str, ip: int,
         "name": name,
         "host": ip,
         "protocol": "sftp",
-        "port": port,
+        "port": int(port),
         "username": user,
         "remotePath": remote,
         "privateKeyPath" : key_path,
